@@ -128,6 +128,7 @@ def preprocessing_nlp(train_ds, model_options, var_df, cat_vocab_dict, keras_mod
             print('    sequence length = %s' %seq_tokens_zip[each_name])
             vocab_size = cat_vocab_dict[each_name]['size_of_vocab']
             best_embedding_size = max(10, vocab_size//400)
+            best_embedding_size = min(512, best_embedding_size)
             print('    recommended embedding_size = %s' %best_embedding_size)
             input_embedding_size = check_model_options(model_options, "embedding_size", best_embedding_size)
             if input_embedding_size != best_embedding_size:
@@ -149,23 +150,35 @@ def preprocessing_nlp(train_ds, model_options, var_df, cat_vocab_dict, keras_mod
     if keras_model_type.lower() in ['bert','nlp','text']:
         if tf_hub:
             tfhub_handle_encoder = model_options['tf_hub_model']
-            bert_model_name = map_hub_to_name[tfhub_handle_encoder]
-            tfhub_handle_preprocess = map_name_to_preprocess[bert_model_name]
+            try:
+                bert_model_name = map_hub_to_name[tfhub_handle_encoder]
+                tfhub_handle_preprocess = map_name_to_preprocess[bert_model_name]
+            except:
+                bert_model_name = 'BERT_given_by_user_input'
+                tfhub_handle_preprocess = "https://tfhub.dev/tensorflow/bert_en_uncased_preprocess/3"
         else:
             tfhub_handle_preprocess = "https://tfhub.dev/tensorflow/bert_en_uncased_preprocess/3"
             tfhub_handle_encoder = 'https://tfhub.dev/tensorflow/small_bert/bert_en_uncased_L-4_H-512_A-8/2'
         preprocessor = hub.KerasLayer(tfhub_handle_preprocess, name='BERT_preprocessing')
         encoder = hub.KerasLayer(tfhub_handle_encoder, trainable=True, name='BERT_encoder')
+        print(f'    BERT model auto-selected: {tfhub_handle_encoder}')
+        print(f'    Preprocessor auto-selected: {tfhub_handle_preprocess}')        
     elif keras_model_type.lower() in ["use"]:
         if tf_hub:
             tfhub_handle_encoder = model_options['tf_hub_model']
-            bert_model_name = map_hub_to_name[tfhub_handle_encoder]
-            tfhub_handle_preprocess = map_name_to_preprocess[bert_model_name]
+            try:
+                bert_model_name = map_hub_to_name[tfhub_handle_encoder]
+                tfhub_handle_preprocess = map_name_to_preprocess[bert_model_name]
+            except:
+                bert_model_name = 'Universal_Sentence_Encoder_given_as_input'
+                tfhub_handle_preprocess = "https://tfhub.dev/tensorflow/bert_en_uncased_preprocess/3"
         else:
             tfhub_handle_preprocess = "https://tfhub.dev/tensorflow/bert_en_uncased_preprocess/3"
             tfhub_handle_encoder = 'https://tfhub.dev/google/universal-sentence-encoder-cmlm/en-base/1'
         preprocessor = hub.KerasLayer(tfhub_handle_preprocess, name='USE_preprocessing')
         encoder = hub.KerasLayer(tfhub_handle_encoder, trainable=False, name='USE_encoder')
+        print(f'    Universal Sentence Encoder auto-selected: {tfhub_handle_encoder}')
+        print(f'    Preprocessor auto-selected: {tfhub_handle_preprocess}')                    
     else:
         if tf_hub:
             #### If it is not BERT, then you don't have to do special preprocessing
@@ -193,38 +206,33 @@ def preprocessing_nlp(train_ds, model_options, var_df, cat_vocab_dict, keras_mod
             if keras_model_type.lower() in ['bert','nlp','text']:
                 nlp_input = tf.keras.layers.Input(shape=(), dtype=tf.string, name=nlp_column)
                 ### You need to do some special pre-processing if it is a BERT model
-                print(f'    BERT model auto-selected: {tfhub_handle_encoder}')
-                print(f'    Preprocessor auto-selected: {tfhub_handle_preprocess}')        
                 x = encoder(preprocessor(nlp_input))['pooled_output']
             elif keras_model_type.lower() in ["use"]:
                 nlp_input = tf.keras.layers.Input(shape=(), dtype=tf.string, name=nlp_column)
                 ### You need to do some special pre-processing if it is a BERT model
-                print(f'    Universal Sentence Encoder auto-selected: {tfhub_handle_encoder}')
-                print(f'    Preprocessor auto-selected: {tfhub_handle_preprocess}')                    
                 x = encoder(preprocessor(nlp_input))["default"]
             else:
                 if tf_hub:
                     # Start by creating an explicit input layer. It needs to have a shape of
                     # (1,) (because we need to guarantee that there is exactly one string
                     # input per batch), and the dtype needs to be 'string'.
-                    nlp_input = tf.keras.layers.Input(shape=(1,), dtype=tf.string, name=nlp_column)
-                    #### If it is not BERT, then you don't have to do special preprocessing
-                    nlp_vectorized = encode_NLP_column(train_ds, nlp_column, nlp_input, 
-                                        vocab_size, sequence_length)
-                    x = encoder(nlp_vectorized)
+                    #nlp_input = tf.keras.layers.Input(shape=(1,), dtype=tf.string, name=nlp_column)
+                    print('If it is not BERT or USE, we cannot build correct preprocessing. Hence ignoring input...')
+                    #nlp_vectorized = encode_NLP_column(train_ds, nlp_column, nlp_input, 
+                    #                    vocab_size, sequence_length)
+                    #x = encoder(nlp_vectorized)
                     #net = outputs['pooled_output']
                     #x = tf.keras.layers.Dropout(0.1)(net)
-                else:
-                    # Start by creating an explicit input layer. It needs to have a shape of
-                    # (1,) (because we need to guarantee that there is exactly one string
-                    # input per batch), and the dtype needs to be 'string'.
-                    nlp_input = tf.keras.layers.Input(shape=(1,), dtype=tf.string, name=nlp_column)
-                    #### If nothing is given, then just choose a basic embedding ######
-                    nlp_vectorized = encode_NLP_column(train_ds, nlp_column, nlp_input, 
-                                            vocab_size, sequence_length)
-                    x = Embedding(max_features+1, embedding_dim, name=nlp_column+'_embedding')(nlp_vectorized)
-                    #x = Flatten()(x)
-                    #x = Dropout(0.25)(x)  ### don't use Dropout after embedding - makes it less accurate!
+                # Start by creating an explicit input layer. It needs to have a shape of
+                # (1,) (because we need to guarantee that there is exactly one string
+                # input per batch), and the dtype needs to be 'string'.
+                nlp_input = tf.keras.layers.Input(shape=(1,), dtype=tf.string, name=nlp_column)
+                #### If nothing is given, then just choose a basic embedding ######
+                nlp_vectorized = encode_NLP_column(train_ds, nlp_column, nlp_input, 
+                                        vocab_size, sequence_length)
+                x = Embedding(max_features+1, embedding_dim, name=nlp_column+'_embedding')(nlp_vectorized)
+                #x = Flatten()(x)
+                #x = Dropout(0.25)(x)  ### don't use Dropout after embedding - makes it less accurate!
             nlp_inputs.append(nlp_input)
             all_nlp_encoded.append(x)
             nlp_col_names.append(nlp_column)
