@@ -423,7 +423,7 @@ def print_regression_model_stats(actuals, predicted, targets='', plot_name=''):
             try:
                 predicted_x = predicted[:,i]
             except:
-                predicted_x = predicted[:]
+                predicted_x = predicted.ravel()
             print('Regression Metrics for Target=%s' %cols[i])
             mae, mae_asp, rmse_asp = print_regression_metrics(actuals_x, predicted_x)
     else:
@@ -662,7 +662,11 @@ def plot_regression_scatters(df, df2, num_vars, kind='scatter', plot_name=''):
                     else:
                         ax1 = ax[k][l]
                         row_color = next(colors)
-                        ax1.hist((x-y), density=True,color = row_color)
+                        try:
+                            assert y.shape[1]
+                            ax1.hist((x-y.ravel()), density=True,color = row_color)
+                        except:
+                            ax1.hist((x-y), density=True,color = row_color)
                         ax1.axvline(color='k')
                         ax1.set_title('Residuals Plot for Target = %s' %num_vars[k])
             except:
@@ -835,6 +839,7 @@ def get_uncompiled_model(inputs, result, output_activation,
     uncompiled_model = Model(inputs=inputs, outputs=outputs)
     return uncompiled_model
 
+#####################################################################################
 def get_compiled_model(inputs, meta_outputs, output_activation, num_predicts, num_labels, 
                        optimizer, val_loss, val_metrics, cols_len, targets):
     model = get_uncompiled_model(inputs, meta_outputs, output_activation, 
@@ -886,15 +891,16 @@ class PrintLR(tf.keras.callbacks.Callback):
   def on_epoch_end(self, epoch, logs=None):
     print('\nLearning rate for epoch {} is {}'.format(epoch + 1,
                                                       self.model.optimizer.lr.numpy()))
-#######################################################################################
+#####################################################################################
 # Function for decaying the learning rate.
 # You can define any decay function you need.
-def schedules(epoch):
-    return 1e-2 * (0.95 ** np.floor(epoch / 2))
+def schedules(epoch, lr):
+    return lr * (0.997 ** np.floor(epoch / 2))
 
+LEARNING_RATE = 0.01
 def decay(epoch):
-    return 0.01 - 0.02 * (0.5 ** (1 + epoch))
-#####################################################################################
+    return LEARNING_RATE - 0.0099 * (0.75 ** (1 + epoch/2))
+#######################################################################################
 import os
 def get_callbacks(val_mode, val_monitor, patience, learning_rate, save_weights_only, steps=100):
     """
@@ -902,6 +908,7 @@ def get_callbacks(val_mode, val_monitor, patience, learning_rate, save_weights_o
     #####    LEARNING RATE SCHEDULING : Setup Learning Rate Multiple Ways #########
     ####################################################################################
     """
+    keras.backend.clear_session()
     logdir = "deep_autoviml"
     callbacks_dict = {}
     tensorboard_logpath = os.path.join(logdir,"mylogs")
@@ -915,10 +922,10 @@ def get_callbacks(val_mode, val_monitor, patience, learning_rate, save_weights_o
                     patience=lr_patience, min_lr=1e-6, mode='auto', min_delta=0.00001, cooldown=0, verbose=1)
 
     ###### This is one variation of onecycle #####
-    onecycle = OneCycleScheduler(steps=steps, lr_max=1e-4)
+    onecycle = OneCycleScheduler(steps=steps, lr_max=0.1)
 
     ###### This is another variation of onecycle #####
-    onecycle2 = OneCycleScheduler2(iterations=steps, max_rate=1e-3)
+    onecycle2 = OneCycleScheduler2(iterations=steps, max_rate=0.05)
 
     lr_sched = keras.callbacks.LearningRateScheduler(schedules)
 
@@ -931,7 +938,7 @@ def get_callbacks(val_mode, val_monitor, patience, learning_rate, save_weights_o
     tb = keras.callbacks.TensorBoard(tensorboard_logpath)
 
     pr = PrintLR()
-    
+
     callbacks_dict['onecycle'] = onecycle
     callbacks_dict['onecycle2'] = onecycle2
     callbacks_dict['cp'] = cp
@@ -959,7 +966,6 @@ def get_chosen_callback(callbacks_dict, keras_options):
     else:
         lr_scheduler = callbacks_dict['lr_sched']
         keras_options['lr_scheduler'] = "lr_sched"
-    print('Selected keras LR scheduler = %s' %keras_options['lr_scheduler'])
     return lr_scheduler
 ################################################################################################
 import math
@@ -986,5 +992,9 @@ class OneCycleScheduler2(keras.callbacks.Callback):
             rate = self._interpolate(2 * self.half_iteration, self.iterations,
                                      self.start_rate, self.last_rate)
         self.iteration += 1
+        if rate < 0:
+            rate = self.start_rate
+            self.iteration = 0
+            K.clear_session()
         K.set_value(self.model.optimizer.lr, rate)
 #####################################################################################################
\ No newline at end of file
